# Refactor code after deployment

- write some tests
- create modules within a `src` directory
- adjust tests accordingly (create a `tests` folder)
- change version numbers when code is changed

## Extra ideas

- Adapt and use another name for the module if you choose (😈)
